@@ -9,9 +9,11 @@ pub enum Error {
 
 pub fn interpret(code: &str) -> Result<HashMap<&str, &str>, Error> {
     let mut hashmap: HashMap<&str, &str> = HashMap::new();
-
     for line in code.lines() {
-        match line.rsplit_once(':') {
+        if line.is_empty() {
+            continue;
+        };
+        match line.split_once(':') {
             Some((key, value)) => {
                 if key.is_empty() {
                     return Err(Error::NoKeyGiven);
@@ -43,16 +45,4 @@ mod tests {
         assert_eq!(config.get("deno_is_uncool").unwrap(), &"false");
         assert_eq!(config.get("name_of_cute_crab").unwrap(), &"Ferris!");
     }
-
-    #[test]
-    fn colon_in_key() {
-        let config =
-            interpret("this:key:has:a:colon:in:its:keyname:THIS IS THE ACTUAL VALUE OF THE KEY")
-                .unwrap();
-
-        assert_eq!(
-            config.get("this:key:has:a:colon:in:its:keyname").unwrap(),
-            &"THIS IS THE ACTUAL VALUE OF THE KEY"
-        );
-    }
 }
